package Music::Tag::Option;
our $VERSION = 0.25;

# Copyright (c) 2006 Edward Allen III. All rights reserved.
#
## This program is free software; you can redistribute it and/or
## modify it under the terms of the Artistic License, distributed
## with Perl.

=pod

=head1 NAME

Music::Tag::Option - Plugin module for Music::Tag to set tags via tag optons 

=head1 SYNOPSIS

use Music::Tag

my $filename = "/var/lib/music/artist/album/track.flac";

my $info = Music::Tag->new($filename, { quiet => 1 }, "ogg");

$info->add_plugin(option, { artist => "Sarah Slean" });

$info->get_info();
   
print "Artist is ", $info->artist;

#Outputs "Artist is Sarah Slean"

=head1 DESCRIPTION

Music::Tag::Option is a plugin to set tags via the plugin option mechanisim.

=over 4

=head1 SET VALUES

=item Any value you would like can be set this way.

=cut


use strict;
our @ISA = qw(Music::Tag::Generic);

sub set_tag {
    my $self = shift;
    my $okmethods = { map { lc($_) => 1 } @{ $self->info->datamethods } };
    while ( my ( $k, $v ) = each %{ $self->options } ) {
        if ( ( defined $v ) and ( $okmethods->{ lc($k) } ) ) {
            $self->info->{ uc($k) } = $v;
            $self->tagchange( uc($k) );
        }
    }
}

sub get_tag { set_tag(@_); }

=pod

=head1 OPTIONS

Any tag accepted by L<Music::Tag>.

=head1 BUGS

No known additional bugs provided by this Module

=head1 SEE ALSO

L<Music::Tag>, L<Music::Tag::Amazon>, L<Music::Tag::File>, L<Music::Tag::FLAC>, L<Music::Tag::Lyrics>,
L<Music::Tag::M4A>, L<Music::Tag::MP3>, L<Music::Tag::MusicBrainz>, L<Music::Tag::OGG>

=head1 AUTHOR 

Edward Allen III <ealleniii _at_ cpan _dot_ org>

=head1 COPYRIGHT

Copyright (c) 2007 Edward Allen III. All rights reserved.

This program is free software; you can redistribute it and/or
modify it under the terms of the Artistic License, distributed
with Perl.


=cut

1;
